==> pcb-rnd_1.2.3.orig.tar.bz2: pcb-rnd-1.2.3/src/stub_mincut.c <==
/*
 *                            COPYRIGHT
 *
 *  pcb-rnd, interactive printed circuit board design
 *  Copyright (C) 2016 Tibor 'Igor2' Palinkas
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include "config.h"
#include <stdlib.h>
#include "stub_mincut.h"
#include "obj_pinvia.h"
#include "obj_pad.h"

static void stub_rat_proc_shorts_dummy(void)
{
}

static void stub_rat_found_short_dummy(pcb_pin_t * pin, pcb_pad_t * pad, const char *with_net)
{
	/* original behavior: just warn at random pins/pads */
	if (pin != NULL)
		PCB_FLAG_SET(PCB_FLAG_WARN, pin);
	if (pad != NULL)
		PCB_FLAG_SET(PCB_FLAG_WARN, pad);

	stub_rat_proc_shorts_dummy();
}

void (*pcb_stub_rat_found_short)(pcb_pin_t * pin, pcb_pad_t * pad, const char *with_net) = stub_rat_found_short_dummy;
void (*pcb_stub_rat_proc_shorts)(void) = stub_rat_proc_shorts_dummy;

==> pcb-rnd_2.0.1.orig.tar.bz2: pcb-rnd-2.0.1/src/stub_mincut.c <==
/*
 *                            COPYRIGHT
 *
 *  pcb-rnd, interactive printed circuit board design
 *  Copyright (C) 2016 Tibor 'Igor2' Palinkas
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *  Contact:
 *    Project page: http://repo.hu/projects/pcb-rnd
 *    lead developer: email to pcb-rnd (at) igor2.repo.hu
 *    mailing list: pcb-rnd (at) list.repo.hu (send "subscribe")
 */

#include "config.h"
#include <stdlib.h>
#include "stub_mincut.h"
#include "obj_common.h"

static void stub_rat_proc_shorts_dummy(void)
{
}

static void stub_rat_found_short_dummy(pcb_any_obj_t *term, const char *with_net)
{
	/* original behavior: just warn at random pins/pads */
	PCB_FLAG_SET(PCB_FLAG_WARN, term);

	stub_rat_proc_shorts_dummy();
}

void (*pcb_stub_rat_found_short)(pcb_any_obj_t *term, const char *with_net) = stub_rat_found_short_dummy;
void (*pcb_stub_rat_proc_shorts)(void) = stub_rat_proc_shorts_dummy;
